@@ -32,12 +32,19 @@ package XAO::DO::Data::CatalogCategoryMap;
 use strict;
 use XAO::Objects;
 use base XAO::Objects->load(objname => 'FS::Hash');
+###############################################################################
+
+use vars qw($VERSION);
+$VERSION=(0+sprintf('%u.%03u',(q$Id: CatalogCategoryMap.pm,v 1.2 2005/01/14 02:08:06 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+
 ###############################################################################
 1;
 __END__
 
 =head1 AUTHORS
 
-Copyright (c) 2001 XAO Inc.
+Copyright (c) 2005 Andrew Maltsev
 
-Andrew Maltsev <am@xao.com>
+Copyright (c) 2001-2004 Andrew Maltsev, XAO Inc.
+
+<am@ejelta.com> -- http://ejelta.com/xao/
